SELECT
    UPKADP.PKPKNR AS "S_Kunde.Kunde",
    NULL AS "S_Adresse.AdressNr",
    UPKADP.PKFAAD AS "S_Adresse.Name1",
    UPKADP.PKLANR AS "S_Adresse.Staat",
    UPKADP.PKORT AS "S_Adresse.Ort",
    UPKADP.PKASOR AS "S_Adresse.Suchbegriff",
    NULL AS "S_Adresse.Selektion",
    NULL AS "S_Adresse.BriefAnrede",
    UPKADP.PKXANR AS "S_Adresse.Anrede",
    NULL AS "S_Adresse.Titel",
    NULL AS "S_Adresse.Vorname",
    UPKADP.PKADR1 AS "S_Adresse.Name2",
    UPKADP.PKADR2 AS "S_Adresse.Name3",
    UPKADP.PKPLZI AS "S_Adresse.PLZ",
    NULL AS "S_Adresse.CityPrefix",
    NULL AS "S_Adresse.CityPostfix",
    NULL AS "S_Adresse.StaatStichwort",
    UPKADP.PKADR3 AS "S_Adresse.Strasse",
    NULL AS "S_Adresse.Hausnummer",
    NULL AS "S_Adresse.Adresszusatz",
    NULL AS "S_Adresse.Bundesland",
    NULL AS "S_Adresse.Postfach",
    NULL AS "S_Adresse.Postfach_PLZ",
    NULL AS "S_Adresse.EMail",
    NULL AS "S_Adresse.HomePage",
    NULL AS "S_Adresse.Handy",
    NULL AS "S_Adresse.Telefon",
    NULL AS "S_Adresse.AutoTelefon",
    NULL AS "S_Adresse.Telefax",
    NULL AS "S_Adresse.Telefon2",
    NULL AS "S_Adresse.Telefax2",
    NULL AS "S_Adresse.Longitude",
    NULL AS "S_Adresse.Latitude",
    NULL AS "S_Kunde.Suchbegriff",
    NULL AS "S_Kunde.Selektion",
    NULL AS "S_Kunde.Verteilergruppe",
    NULL AS "S_Kunde.Branche",
    NULL AS "S_Kunde.Region",
    NULL AS "S_Kunde.Sachbearbeiter",
    NULL AS "S_Kunde.Sprache",
    NULL AS "S_Kunde.Abc_klasse",
    NULL AS "S_Kunde.Artikelstatistik",
    NULL AS "S_Kunde.Webshop",
    NULL AS "S_Kunde.Bestandsfaktor",
    NULL AS "S_Kunde.Lieferlagerort",
    NULL AS "S_Kunde.Kunde_seit",
    NULL AS "S_Kunde.lieferantennummer",
    NULL AS "S_Kunde.inlaendische_steuernr",
    NULL AS "S_Kunde.waehrung",
    NULL AS "S_UStID.UStID",
    NULL AS "S_Kunde.rechnungsintervall",
    NULL AS "S_Kunde.rechnungskennzeichen",
    NULL AS "S_Kunde.rechnung_an",
    NULL AS "S_Kunde.konzern",
    NULL AS "S_Kunde.verband",
    NULL AS "S_Kunde.kassensperre",
    NULL AS "S_Kunde.kreditversicherung",
    NULL AS "S_Kunde.kreditversicherer",
    NULL AS "S_Kunde.kredit_limit_versichert",
    NULL AS "S_Kunde.kreditversicherung_ab",
    NULL AS "S_Kunde.lst_auftragsnr",
    NULL AS "S_Kunde.mahnsperre",
    NULL AS "S_Kunde.sepa_mandat",
    NULL AS "S_Kunde.sepa_mandatsreferenz",
    NULL AS "S_Kunde.sepa_mandatdat",
    NULL AS "S_Kunde.steueridpruefen",
    NULL AS "S_Kunde.stgr_ohne_st",
    NULL AS "S_Kunde.stgreu_mit_st",
    NULL AS "S_Kunde.stgreu_ohne_st",
    NULL AS "S_Kunde.stgraus_mit_st",
    NULL AS "S_Kunde.stgraus_ohne_st",
    NULL AS "S_Kunde.zahlungsart",
    NULL AS "S_Kunde.RemittanceAdvice",
    NULL AS "S_Kunde.zahlungsziel",
    UPKADP.PKKRLM AS "S_Kunde.kreditlimit",
    NULL AS "S_Kunde.kreditlimit_ueberwachen",
    NULL AS "S_Kunde.mahnverfahren",
    NULL AS "F_KundeVerzug.verzug",
    NULL AS "F_KundeVerzug.gueltig_ab",
    NULL AS "F_KundeVerzug.manuell",
    NULL AS "S_Kunde.versandart",
    NULL AS "S_Kunde.lieferbedingung",
    NULL AS "S_Kunde.lieferhinweis",
    NULL AS "S_Kunde.vk_preisgruppe",
    NULL AS "S_Kunde.vk_kondition",
    NULL AS "S_Kunde.rabattgruppe",
    NULL AS "S_Kunde.rabatt2gruppe",
    NULL AS "S_Kunde.rabatt3gruppe",
    NULL AS "S_Kunde.provgruppe",
    NULL AS "S_Kunde.statistikgruppe",
    NULL AS "S_Kunde.erloeskonto",
    NULL AS "S_Kunde.erloesgruppe",
    NULL AS "S_Kunde.incoterms",
    NULL AS "S_Kunde.incoterms_ort",
    NULL AS "S_Kunde.lieferland",
    NULL AS "S_Kunde.lieferbedmerk",
    NULL AS "S_Kunde.mwstpflichttatbestand",
    NULL AS "S_Kunde.kundensegment",
    NULL AS "S_Kunde.bundesland",
    NULL AS "S_Kunde.gelangensbestaetigung",
    NULL AS "S_Kunde.transportzone",
    NULL AS "S_Kunde.intrastat",
    NULL AS "S_Kunde.zollnummer",
    NULL AS "S_Kunde.intrastatgruppe",
    NULL AS "S_Kunde.eccn",
    NULL AS "S_Kunde.zugelassenewa",
    NULL AS "S_Kunde.kreditor",
    NULL AS "S_Kunde.finanzamt",
    NULL AS "S_Kunde.steuer_nr",
    NULL AS "S_Kunde.sperre",
    NULL AS "S_Kunde.status",
    NULL AS "S_Kunde.mahnsperre_von",
    NULL AS "S_Kunde.mahnsperre_bis",
    NULL AS "S_Kunde.provisionssperre",
    NULL AS "S_Kunde.bonusgruppe",
    NULL AS "S_Kunde.intrastatsperre",
    NULL AS "S_Kunde.fibu_sachbearbeiter",
    NULL AS "S_Kunde.erloesgruppe_faelligkeit",
    NULL AS "S_Kunde.erloeskonto_skonti",
    NULL AS "S_Kunde.bewertungsklasse",
    NULL AS "S_Kunde.rabattgruppe2",
    NULL AS "S_Kunde.rabattgruppe3",
    NULL AS "S_Kunde.zinsberechnung",
    NULL AS "S_Kunde.zinssatz",
    NULL AS "S_Kunde.mindestzinsbetrag",
    NULL AS "S_Kunde.zinslauf_von",
    NULL AS "S_Kunde.zinslauf_bis",
    NULL AS "S_Kunde.bankleitzahl",
    NULL AS "S_Kunde.bankkonto",
    NULL AS "S_Kunde.iban",
    NULL AS "S_Kunde.bic",
    NULL AS "S_Kunde.bankland",
    NULL AS "S_Kunde.bankname",
    NULL AS "S_Kunde.bankplz",
    NULL AS "S_Kunde.bankort",
    NULL AS "S_Kunde.sepa_lastschrift",
    NULL AS "S_Kunde.mandatsreferenz",
    NULL AS "S_Kunde.mandatgueltigab",
    NULL AS "S_Kunde.mandatgueltigbis",
    NULL AS "S_Kunde.lst_auftrag_abgerechnet",
    NULL AS "S_Kunde.textnr",
    NULL AS "S_Kunde.kundengruppe",
    NULL AS "S_Kunde.vertreter",
    NULL AS "S_Kunde.provisionsbasis",
    NULL AS "S_Kunde.preisfindung_methode",
    NULL AS "S_Kunde.preisgruppe",
    NULL AS "S_Kunde.rabatt",
    NULL AS "S_Kunde.rabatt2",
    NULL AS "S_Kunde.rabatt3",
    NULL AS "S_Kunde.statistik",
    NULL AS "S_Kunde.ursprungsland",
    NULL AS "S_Kunde.exportkontrolle",
    NULL AS "S_Kunde.niederlassung",
    NULL AS "S_Kunde.umsatzsteuerbefreit",
    NULL AS "S_Kunde.ustid_geprueft",
    NULL AS "S_Kunde.ustid_letztepruefung",
    NULL AS "S_Kunde.ustid_bemerkung",
    NULL AS "S_Kunde.ustid_dokustatus",
    NULL AS "S_Kunde.P_AddPrefix4JPK",
    NULL AS "S_Kunde.P_TaxTransfer2DC",
    NULL AS "S_Kunde.cRU_IEC",
    NULL AS "S_Kunde.cRU_Rclassifyer",
    NULL AS "S_Kunde.cRU_DocIdentPers",
    NULL AS "S_Kunde.cRU_ForeignTaxID",
    NULL AS "S_Kunde.cRU_PrimStRegNr",
    NULL AS "S_Kunde.cRU_PrimStRegDa",
    NULL AS "S_Kunde.cRU_EntCertRegNo",
    NULL AS "S_Kunde.cRU_EntCerRegdate",
    NULL AS "S_kunde.uCA_Betriebskalender",
    NULL AS "S_kunde.uCW_RestrictionListing",
    NULL AS "S_Kunde.uCW_MinDaysToExp",
    NULL AS "S_Kunde.uCW_DirectPrintInvoice",
    NULL AS "S_Kunde.uCW_VerpVorschrift",
    NULL AS "S_kunde.uCW_Betriebskalender",
    NULL AS "S_Kunde.uCI_Sammellieferschein",
    NULL AS "S_Kunde.OaPText",
    NULL AS "S_Kunde.OutputType_EntryCertificate",
    NULL AS "S_Kunde.SuppECLabels"
FROM UPKADP;
